import webpack from "webpack";
import path from "path";
const ExtractTextPlugin = require("extract-text-webpack-plugin");

export default {
  debug: true,
  devtool: "cheap-module-eval-source-map",
  noInfo: false,
  entry: [
    "eventsource-polyfill", // necessary for hot reloading with IE
    "webpack-hot-middleware/client?reload=true", //note that it reloads the page if hot module reloading fails.
    "./client-app/index"
  ],
  target: "web",
  output: {
    path: __dirname + "/dist", // Note: Physical files are only output by the production build task `npm run build`.
    publicPath: "/",
    filename: "bundle.js"
  },
  devServer: {
    contentBase: "./client-app"
  },
  plugins: [
    new webpack.HotModuleReplacementPlugin(),
    new webpack.NoErrorsPlugin(),
    new ExtractTextPlugin("style.scss")
  ],
  module: {
    loaders: [
      {
        test: /\.js$/,
        include: path.join(__dirname, "client-app"),
        loaders: ["babel"]
      },
      {
        test: /\.scss$/,
        loader: "style-loader!css-loader?modules&importLoaders=1"
      },
      {
        test: /(\.css)$/,
        loaders: ["style", "css"]
      },

      { test: /\.eot(\?v=\d+\.\d+\.\d+)?$/, loader: "file" },
      { test: /\.(woff|woff2)$/, loader: "url?prefix=font/&limit=5000" },
      {
        test: /\.ttf(\?v=\d+\.\d+\.\d+)?$/,
        loader: "url?limit=10000&mimetype=application/octet-stream"
      },
      {
        test: /\.svg(\?v=\d+\.\d+\.\d+)?$/,
        loader: "url?limit=10000&mimetype=image/svg+xml"
      },
      {
        test: /\.json$/,
        loader: "json-loader"
      }
    ]
  }
};
